@@ -36,35 +36,37 @@ class Weather:
             print(res_json)
         #If success, writing output to a file
         else:
-
-            filename = f"weather_forecast of {city_name} {datetime.datetime.now().strftime('%Y-%m-%d_%I-%M-%S-%p')}.txt"
-            # create a file with filename variable in append format
-            #print('filename given')
-            with open(filename,'a') as f:
-                y = x['list'][day]['main']
-                z = x['list'][day]['weather']
-                # store the temperature value corresponding to value of y
-                current_temperature = y["temp"]
-                # store the pressure value corresponding to value of y
-                current_pressure = y["pressure"]
-                # store the humidity value corresponding to value of y
-                current_humidity = y["humidity"]
-                # store the weather description value corresponding to value of z
-                weather_description = z[0]["description"]
-                # write necessary info in file
-                f.write(f'The forecasted weather of {city_name} on {date}')
-                f.write("\n")
-                f.write(f'Temperature (in kelvin unit) = {current_temperature}' )
-                f.write("\n")
-                f.write(f'Atmospheric pressure (in hPa unit) = {current_pressure}' )
-                f.write("\n")
-                f.write(f'Humidity (in percentage) = {current_humidity}' )
-                f.write("\n")
-                f.write(f'Description = {weather_description}' )
-                f.write("\n")
-                f.write("\n")
-                # closing the file
-                f.close()
+            for day in range(0,6):
+                date = x['list'][day]['dt_txt']
+                only_date = date.split()
+                filename = f"weather_forecast of {city_name} {datetime.datetime.now().strftime('%Y-%m-%d_%I-%M-%S-%p')}.json"
+                # create a file with filename variable in append format
+                #print('filename given')
+                with open(filename,'a') as f:
+                    y = data['list'][day]['main']
+                    z = data['list'][day]['weather']
+                    # store the temperature value corresponding to value of y
+                    current_temperature = y["temp"]
+                    # store the pressure value corresponding to value of y
+                    current_pressure = y["pressure"]
+                    # store the humidity value corresponding to value of y
+                    current_humidity = y["humidity"]
+                    # store the weather description value corresponding to value of z
+                    weather_description = z[0]["description"]
+                    # write necessary info in file
+                    f.write(f'The forecasted weather of {city_name} on {date}')
+                    f.write("\n")
+                    f.write(f'Temperature (in kelvin unit) = {current_temperature}' )
+                    f.write("\n")
+                    f.write(f'Atmospheric pressure (in hPa unit) = {current_pressure}' )
+                    f.write("\n")
+                    f.write(f'Humidity (in percentage) = {current_humidity}' )
+                    f.write("\n")
+                    f.write(f'Description = {weather_description}' )
+                    f.write("\n")
+                    f.write("\n")
+                    # closing the file
+                    f.close()
             '''
             with open('result.json', 'w') as f:
                 json.dump(data, f)
